@@ -1,7 +1,7 @@
 #ifndef TYPEDEF_H
 #define TYPEDEF_H
 
-typedef int Trixel;
+typedef unsigned int   Trixel;
 typedef unsigned short BufNum;
 
 #endif
