@@ -19,6 +19,7 @@
 
 #include <QtDBus/QtDBus>
 #include <kxmlguiwindow.h>
+#include <QtDeclarative/QDeclarativeView>
 
 #include <config-kstars.h>
 
@@ -26,6 +27,7 @@
 #include "oal/equipmentwriter.h"
 #include "oal/observeradd.h"
 
+class WIUserSettings;
 // forward declaration is enough. We only need pointers
 class QPalette;
 class KActionMenu;
@@ -36,12 +38,17 @@ class SkyMap;
 class GeoLocation;
 class FindDialog;
 class TimeStepBox;
+class ImageExporter;
 
 class GUIManager;
 class DriverManager;
 
 class AltVsTime;
 class WUTDialog;
+class WIView;
+class WILPSettings;
+class WIEquipSettings;
+class ObsConditions;
 class AstroCalc;
 class SkyCalendar;
 class ScriptBuilder;
@@ -165,6 +172,10 @@ public:
 
     void selectPreviousFov();
 
+    void showWISettingsUI();
+
+    void showWI(ObsConditions *obs);
+
 public Q_SLOTS:
     /**DBUS interface function.
      * Set focus to given Ra/Dec coordinates
@@ -312,10 +323,51 @@ public Q_SLOTS:
 
     /**DBUS interface function.  Export the sky image to a file.
      * @param filename the filename for the exported image
-     * @param width the width for the exported image
-     * @param height the height for the exported image
+     * @param width the width for the exported image. Map's width will be used if nothing or an invalid value is supplied.
+     * @param height the height for the exported image. Map's height will be used if nothing or an invalid value is supplied.
+     * @param includeLegend should we include a legend?
      */
-    Q_SCRIPTABLE Q_NOREPLY void exportImage( const QString &filename, int width, int height );
+    Q_SCRIPTABLE Q_NOREPLY void exportImage( const QString &filename, int width = -1, int height = -1, bool includeLegend = false );
+
+    /**DBUS interface function.  Return a URL to retrieve Digitized Sky Survey image.
+     * @param objectName name of the object.
+     * @note If the object is note found, the string "ERROR" is returned.
+     */
+    Q_SCRIPTABLE QString getDSSURL( const QString &objectName );
+
+    /**DBUS interface function.  Return a URL to retrieve Digitized Sky Survey image.
+     * @param RA_J2000 J2000.0 RA
+     * @param Dec_J2000 J2000.0 Declination
+     * @param width width of the image, in arcminutes (default = 15)
+     * @param height height of the image, in arcminutes (default = 15)
+     */
+    Q_SCRIPTABLE QString getDSSURL( double RA_J2000, double Dec_J2000, float width = 15, float height = 15 );
+
+    /**DBUS interface function.  Return XML containing information about a sky object
+     * @param objectName name of the object.
+     * @note If the object was not found, the XML is empty.
+     */
+    Q_SCRIPTABLE QString getObjectDataXML( const QString &objectName );
+
+    /**DBUS interface function.  Set the approx field-of-view
+     * @param FOV_Degrees field of view in degrees
+     */
+    Q_SCRIPTABLE Q_NOREPLY void setApproxFOV( double FOV_Degrees );
+
+    /**DBUS interface function.  Get the dimensions of the Sky Map.
+     * @return a string containing widthxheight in pixels.
+     */
+    Q_SCRIPTABLE QString getSkyMapDimensions();
+
+    /**DBUS interface function.  Return a newline-separated list of objects in the observing wishlist.
+     * @note Unfortunately, unnamed objects are troublesome. Hopefully, we don't have them on the observing list.
+     */
+    Q_SCRIPTABLE QString getObservingWishListObjectNames();
+
+    /**DBUS interface function.  Return a newline-separated list of objects in the observing session plan.
+     * @note Unfortunately, unnamed objects are troublesome. Hopefully, we don't have them on the observing list.
+     */
+    Q_SCRIPTABLE QString getObservingSessionPlanObjectNames();
 
     /**DBUS interface function.  Print the sky image.
      * @param usePrintDialog if true, the KDE print dialog will be shown; otherwise, default parameters will be used
@@ -440,6 +492,9 @@ public Q_SLOTS:
     /** Apply new settings and redraw skymap */
     void slotApplyConfigChanges();
 
+    /** Apply new settings for WI */
+    void slotApplyWIConfigChanges();
+
     /** Called when zoom level is changed. Enables/disables zoom
      *  actions and updates status bar. */
     void slotZoomChanged();
@@ -498,6 +553,12 @@ private slots:
     /** action slot: open What's up tonight dialog */
     void slotWUT();
 
+    /** action slot: open What's Interesting settings window */
+    void slotWISettings();
+
+    /** action slot: open What's Interesting window */
+    void slotShowWIView(int status);
+
     /** action slot: open Sky Calendar tool */
     void slotCalendar();
 
@@ -634,6 +695,7 @@ private:
 
     FindDialog *findDialog;
     ExportImageDialog *imgExportDialog;
+    ImageExporter *imageExporter;
 
     //FIXME: move to KStarsData
     ObservingList *obsList;
@@ -642,6 +704,11 @@ private:
     Execute *execute;
     AltVsTime *avt;
     WUTDialog *wut;
+    WIView *wi;
+    WILPSettings *wiLPSettings;
+    WIEquipSettings *wiEquipSettings;
+    ObsConditions *wiObsConditions;
+    QDockWidget *wiDock;
     SkyCalendar *skycal;
     ScriptBuilder *sb;
     PlanetViewer *pv;
