@@ -27,12 +27,12 @@
 #include "skymap.h"
 #include "simclock.h"
 #include "ksnumbers.h"
+#include "version.h"
 #include "Options.h"
 //Added by qt3to4:
 #include <QPixmap>
 #include <kglobal.h>
 
-#define KSTARS_VERSION "2.0.0"
 
 static const char description[] =
     I18N_NOOP("Desktop Planetarium");
@@ -62,10 +62,13 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(ki18n("Henry de Valence"), KLocalizedString(), "hdevalence@gmail.com");
     aboutData.addAuthor(ki18n("Samikshan Bairagya"), KLocalizedString(), "samikshan.bairagya@kdemail.net");
     aboutData.addAuthor(ki18n("Rafał Kułaga"), KLocalizedString(), "rl.kulaga@gmail.com");
+    aboutData.addAuthor(ki18n("Rishab Arora"), KLocalizedString(), "ra.rishab@gmail.com");
+
     aboutData.addCredit(ki18n("Valery Kharitonov"), ki18n("Converted labels containing technical terms to links to documentation") );
     aboutData.addCredit(ki18n("Ana-Maria Constantin"), ki18n("Technical documentation on Astronomy and KStars") );
     aboutData.addCredit(ki18n("Andrew Stepanenko"), ki18n("Guiding code based on lin_guider") );
     aboutData.addCredit(ki18n("Nuno Pinheiro"), ki18n("Artwork") );
+
     KCmdLineArgs::init( argc, argv, &aboutData );
 
     KCmdLineOptions options;
