@@ -316,7 +316,7 @@ void StarObject::JITupdate()
     if ( updateNumID != data->updateNumID() ) {
         // TODO: This can be optimized and reorganized further in a better manner.
         // Maybe we should do this only for stars, since this is really a slow step only for stars
-        Q_ASSERT( isfinite( lastPrecessJD ) );
+        Q_ASSERT( std::isfinite( lastPrecessJD ) );
         if( ( lastPrecessJD - data->updateNum()->getJD() ) >= 0.0005 // TODO: Make this 0.0005 a constant / define it
             || ( lastPrecessJD - data->updateNum()->getJD() ) <= -0.0005
             || Options::alwaysRecomputeCoordinates()
